=======
mscales
=======

`mscales` is a Python package to generate, visualize,
and sonify musical scales.

.. image:: _static/asemic_sounds.png
   :align: center
   :alt: "Asemic sounds" by Cecil Touchon (Image taken from https://pin.it/13REi6v).

.. toctree::
   :caption: Contents
   :maxdepth: 2

   quickstart
   scales
   pcsets

.. toctree::
   :maxdepth: 1
   :hidden:

   release-history
